TimeLock

Struct TimeLock 

pub struct TimeLock {
    pub expiry: SystemTime,
    pub expired: bool,
}
A struct that represents a time-based lock mechanism, which tracks an expiration time and provides functionality to check if the lock has expired.

Fields

expiry: SystemTimeexpired: bool

Implementations

Source

impl TimeLock

pub fn is_expired(&mut self) -> bool

Checks if the TimeLock has expired by comparing the current system time with the expiration time. Once the lock has expired, it will set the expired flag to true and return the result.

Returns
  • true if the lock has expired, false otherwise.